.. include:: overview.rst

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Contents:

   Overview <self>
   installation

.. toctree::
   :glob:
   :hidden:
   :maxdepth: 1
   :caption: Tutorials

   notebooks/*

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: References

   API Reference <modules>
   contributing

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
